@@ -25,6 +25,7 @@
 #include <QButtonGroup>
 
 #include "mailtransport_debug.h"
+#include <KAuthorized>
 #include <KMessageBox>
 #include <KProtocolInfo>
 
@@ -77,7 +78,7 @@ public:
         }
 
         ui.authCombo->clear();
-        for (int authType : qAsConst(capa)) {
+        for (int authType : std::as_const(capa)) {
             addAuthenticationItem(ui.authCombo, authType);
         }
 
@@ -136,6 +137,7 @@ void SMTPConfigWidget::init()
     d->serverTestFailed = false;
 
     d->ui.setupUi(this);
+    d->ui.password->setRevealPasswordAvailable(KAuthorized::authorize(QStringLiteral("lineedit_reveal_password")));
     d->manager->addWidget(this); // otherwise it doesn't find out about these widgets
     d->manager->updateWidgets();
 
@@ -161,11 +163,7 @@ void SMTPConfigWidget::init()
     connect(d->ui.checkCapabilities, &QPushButton::clicked, this, &SMTPConfigWidget::checkSmtpCapabilities);
     connect(d->ui.kcfg_host, &QLineEdit::textChanged, this, &SMTPConfigWidget::hostNameChanged);
 
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    connect(d->encryptionGroup, qOverload<int>(&QButtonGroup::buttonClicked), this, &SMTPConfigWidget::encryptionChanged);
-#else
     connect(d->encryptionGroup, qOverload<QAbstractButton *>(&QButtonGroup::buttonClicked), this, &SMTPConfigWidget::encryptionAbstractButtonChanged);
-#endif
     connect(d->ui.kcfg_requiresAuthentication, &QCheckBox::toggled, this, &SMTPConfigWidget::ensureValidAuthSelection);
     connect(d->ui.kcfg_storePassword, &QCheckBox::toggled, this, &SMTPConfigWidget::enablePasswordLine);
     if (!d->transport->isValid()) {
