@@ -7,14 +7,14 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MAILTRANSPORT_TRANSPORTMANAGEMENTWIDGET_H
-#define MAILTRANSPORT_TRANSPORTMANAGEMENTWIDGET_H
+#pragma once
 
 #include <mailtransport_export.h>
 
 #include <QWidget>
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
   A widget to manage mail transports.
 */
@@ -40,4 +40,3 @@ private:
 };
 } // namespace MailTransport
 
-#endif // MAILTRANSPORT_TRANSPORTMANAGEMENTWIDGET_H
